@@ -8,3 +8,9 @@ WebCrawlerBase = web_crawler_base.WebCrawlerBase
 
 from hawkdata.utils.crawlers import em_crawler
 EmCrawler = em_crawler.EmCrawler
+
+from hawkdata.utils.crawlers import sf_crawler
+SfCrawler = sf_crawler.SfCrawler
+
+from hawkdata.utils.crawlers import cb_crawler
+CbCrawler = cb_crawler.CbCrawler
